API reference
=============

This section documents the public Python API.

If you build the docs without installing optional framework dependencies,
configure autodoc mocking or install the extras in your docs environment.

Framework integrations
^^^^^^^^^^^^^^^^^^^^^^

.. toctree::
   :maxdepth: 2

   fastapi
   flask
   quart
   django
   tornado
   litestar

Core
^^^^

.. toctree::
   :maxdepth: 2

   core
